@@ -6,29 +6,20 @@ package VCS::Which::Plugin;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
+use Moo;
 use strict;
 use warnings;
 use version;
 use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
-use base qw/Exporter/;
 use File::chdir;
 
-our $VERSION     = version->new('0.5.9');
-our @EXPORT_OK   = qw//;
-our %EXPORT_TAGS = ();
+our $VERSION = version->new('0.6.0');
 
-sub new {
-    my $caller = shift;
-    my $class  = ref $caller ? ref $caller : $caller;
-    my %param  = @_;
-    my $self   = \%param;
-
-    bless $self, $class;
-
-    return $self;
-}
+has [qw/_installed _base/] => (
+    is => 'rw',
+);
 
 sub name {
     my ($self) = @_;
@@ -131,7 +122,7 @@ VCS::Which::Plugin - Base class for the various VCS plugins
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin version 0.5.9.
+This documentation refers to VCS::Which::Plugin version 0.6.0.
 
 =head1 SYNOPSIS
 
