@@ -6,18 +6,20 @@ package VCS::Which::Plugin::Bazaar;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
+use Moo;
 use strict;
 use warnings;
 use version;
 use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
-use base qw/VCS::Which::Plugin/;
 use Path::Tiny;
 use File::chdir;
 use Contextual::Return;
 
-our $VERSION = version->new('0.5.9');
+extends 'VCS::Which::Plugin';
+
+our $VERSION = version->new('0.6.0');
 our $name    = 'Bazaar';
 our $exe     = 'bzr';
 our $meta    = '.bzr';
@@ -25,15 +27,15 @@ our $meta    = '.bzr';
 sub installed {
     my ($self) = @_;
 
-    return $self->{installed} if exists $self->{installed};
+    return $self->_installed if defined $self->_installed;
 
     for my $path (split /[:;]/, $ENV{PATH}) {
         next if !-x "$path/$exe";
 
-        return $self->{installed} = 1;
+        return $self->_installed( 1 );
     }
 
-    return $self->{installed} = 0;
+    return $self->_installed( 0 );
 }
 
 sub used {
@@ -50,7 +52,7 @@ sub used {
 
     while ($current_dir) {
         if ( -d "$current_dir/$meta" ) {
-            $self->{base} = $current_dir;
+            $self->_base( $current_dir );
             return $level;
         }
 
@@ -68,7 +70,7 @@ sub used {
 sub uptodate {
     my ( $self, $dir ) = @_;
 
-    $dir ||= $self->{base};
+    $dir ||= $self->_base;
 
     croak "'$dir' is not a directory!" if !-e $dir;
 
@@ -81,7 +83,7 @@ sub uptodate {
 sub pull {
     my ( $self, $dir ) = @_;
 
-    $dir ||= $self->{base};
+    $dir ||= $self->_base;
 
     croak "'$dir' is not a directory!" if !-e $dir;
 
@@ -164,7 +166,7 @@ VCS::Which::Plugin::Bazaar - The Bazaar plugin for VCS::Which
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin::Bazaar version 0.5.9.
+This documentation refers to VCS::Which::Plugin::Bazaar version 0.6.0.
 
 =head1 SYNOPSIS
 
