@@ -6,18 +6,20 @@ package VCS::Which::Plugin::Git;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
+use Moo;
 use strict;
 use warnings;
 use version;
 use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
-use base qw/VCS::Which::Plugin/;
 use Path::Tiny;
 use File::chdir;
 use Contextual::Return;
 
-our $VERSION = version->new('0.5.9');
+extends 'VCS::Which::Plugin';
+
+our $VERSION = version->new('0.6.0');
 our $name    = 'Git';
 our $exe     = 'git';
 our $meta    = '.git';
@@ -25,15 +27,15 @@ our $meta    = '.git';
 sub installed {
     my ($self) = @_;
 
-    return $self->{installed} if exists $self->{installed};
+    return $self->_installed if defined $self->_installed;
 
     for my $path (split /[:;]/, $ENV{PATH}) {
         next if !-x "$path/$exe";
 
-        return $self->{installed} = 1;
+        return $self->_installed( 1 );
     }
 
-    return $self->{installed} = 0;
+    return $self->_installed( 0 );
 }
 
 sub used {
@@ -50,7 +52,7 @@ sub used {
 
     while ($current_dir) {
         if ( -d "$current_dir/$meta" ) {
-            $self->{base} = $current_dir;
+            $self->_base( $current_dir );
             return $level;
         }
 
@@ -68,7 +70,7 @@ sub used {
 sub uptodate {
     my ( $self, $dir ) = @_;
 
-    $dir ||= $self->{base};
+    $dir ||= $self->_base;
 
     croak "'$dir' is not a directory!" if !-d $dir;
 
@@ -81,7 +83,7 @@ sub uptodate {
 sub pull {
     my ( $self, $dir ) = @_;
 
-    $dir ||= $self->{base};
+    $dir ||= $self->_base;
 
     croak "'$dir' is not a directory!" if !-e $dir;
 
@@ -92,7 +94,7 @@ sub pull {
 sub push {
     my ( $self, $dir ) = @_;
 
-    $dir ||= $self->{base};
+    $dir ||= $self->_base;
 
     croak "'$dir' is not a directory!" if !-e $dir;
 
@@ -105,7 +107,7 @@ sub cat {
 
     # git expects $file to be relative to the base of the git repo not the
     # current directory so we change it to being relative to the repo if nessesary
-    my $repo_dir = path($self->{base}) or confess "How did I get here with out a base directory?\n";
+    my $repo_dir = path($self->_base) or confess "How did I get here with out a base directory?\n";
     my $cwd      = path('.')->absolute;
     local $CWD = $CWD;
 
@@ -124,7 +126,7 @@ sub cat {
             die "Git.pm is not installed only propper revision names can be used\n";
         }
 
-        my $repo = Git->repository(Directory => $self->{base});
+        my $repo = Git->repository(Directory => $self->_base);
         my @revs = reverse $repo->command('rev-list', '--all', '--', $file);
         my $rev = $revision =~ /^[-]?\d+$/xms && $revs[$revision] ? $revs[$revision] : $revision;
 
@@ -217,7 +219,7 @@ sub versions {
         die "Git.pm is not installed only propper revision names can be used\n";
     }
 
-    my $repo = Git->repository(Directory => $self->{base});
+    my $repo = Git->repository(Directory => $self->_base);
     my @revs = reverse $repo->command('rev-list', '--all', '--', path($file)->absolute);
 
     return @revs;
@@ -256,6 +258,12 @@ sub status {
         $status{added} = \@added;
     }
 
+    my @committed = split /Changes to be committed:\n/, $status;
+    if (@committed > 1) {
+        my $new = pop @committed;
+        $status{committed} = [ $new =~ /^\t[^:]+:\s+(.*?)\n/gxms ];
+    }
+
     my @untracked = split /Untracked files:\n/, $status;
     if ( @untracked > 1 ) {
         my $untracked = pop @untracked;
@@ -265,14 +273,22 @@ sub status {
         else {
             $untracked =~ s/^[#].*?\n//gxms;
         }
-        $status{untracked} = [ grep {$_} map {chomp; $_} split /\n?[#]?\s+/, $untracked ];
+
+        if ($untracked =~ /^[#]/xms) {
+            $status{untracked} = [ grep {$_} map {chomp; $_} split /\n?[#]\s+/, $untracked ];
+        }
+        else {
+            $status{untracked} = [ $untracked =~ /^\t(.*?)\n/gxms ];
+        }
     }
 
-    $status{merge} = $status =~ /
+    if ($status =~ /
         You \s+ have \s+ unmerged \s+ paths[.]$
         |
         All \s+ conflicts \s+ fixed \s+ but \s+ you \s+ are \s+ still \s+ merging[.]$
-    /xms;
+    /xms) {
+        $status{merge} = 1;
+    }
 
     return \%status;
 }
@@ -300,7 +316,7 @@ VCS::Which::Plugin::Git - The Git plugin for VCS::Which
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin::Git version 0.5.9.
+This documentation refers to VCS::Which::Plugin::Git version 0.6.0.
 
 =head1 SYNOPSIS
 
